@@ -1,8 +1,13 @@
+"""
+vb - pyvb module that holds the implementaton of the VB class
+that is meant to be instantiated as a singleton.
+"""
 from pyvb.constants import *
 from pyvb.command import *
 from pyvb.vm import *
 from pyvb.ostype import *
 from pyvb.dvd import *
+from pyvb.hdd import *
 
 class VB:
 	def __init__(self):
@@ -40,6 +45,16 @@ class VB:
 		command.run()
 		return parser.parse(command.read)
 	
+	def listHdds(self, uuid=None):
+		if uuid:
+			cmd='%s %s'%(VB_COMMAND_SHOWVDIINFO, uuid)
+			command=VBCommand(command=cmd)
+		else:
+			command=VBCommand(command=VB_COMMAND_LIST_HDDS)
+		parser=vbHddParser()
+		command.run()
+		return parser.parse(command.read)
+	
 	def getVM(self, uuid):
 		try:
 			return self.listVMS(uuid)[0]
@@ -54,4 +69,19 @@ class VB:
 	def poweroffVM(self, vm):
 		cmd='%s %s %s'%(VB_COMMAND_CONTROLVM, vm.getUUID(), 'poweroff')
 		command=VBCommand(command=cmd)
+		command.run()
+		
+	def acpipoweroffVM(self, vm):
+		cmd='%s %s %s'%(VB_COMMAND_CONTROLVM, vm.getUUID(), 'acpipowerbutton')
+		command=VBCommand(command=cmd)
+		command.run()
+		
+	def pauseVM(self, vm):
+		cmd='%s %s %s'%(VB_COMMAND_CONTROLVM, vm.getUUID(), 'pause')
+		command=VBCommand(command=cmd)
+		command.run()
+		
+	def resumeVM(self, vm):
+		cmd='%s %s %s'%(VB_COMMAND_CONTROLVM, vm.getUUID(), 'resume')
+		command=VBCommand(command=cmd)
 		command.run()
\ No newline at end of file
